import requests
import pytest
import allure
from config.readConfig import ReadConfig
rc = ReadConfig()
null = None

@allure.feature("XZS-学生列表功能链路测试")
class TestXzsDemo3():

    case_1 = [({"userName":"","role":1,"pageIndex":1,"pageSize":10},{"code":1}),
              ({"role":1,"pageIndex":1,"pageSize":10},{"code":0})]           # code == 1  1 != 0

    @pytest.mark.parametrize("data,code", case_1)
    @pytest.mark.run(order=1)
    @allure.severity(allure.severity_level.BLOCKER)
    @pytest.mark.flaky(reruns=3, reruns_delay=2)
    @allure.title("查询所有用户名")
    @allure.story("查询所有用户名：/api/admin/user/page/list")
    def test_case_01(self,data,code,get_xzs_cookie):
        """
        查询所有用户名接口：/api/admin/user/page/list
        post
        {"userName":"","role":1,"pageIndex":1,"pageSize":10}
        """
        res = requests.post(url=rc.get_xzsconfig() + "/api/admin/user/page/list",json=data,headers=get_xzs_cookie)
        print(res.text)
        assert res.status_code == 200
        assert res.json()["code"] == code.get("code")

    case_2 = [({"userName": "student", "role": 1, "pageIndex": 1, "pageSize": 10}, {"code": 1}),
              ({"userName": "@#$%$^","role": 1, "pageIndex": 1, "pageSize": 10}, {"code": 0}),    #code  ==1  1 != 0
              ({"userName": "@#$%$^","role": 1, "pageIndex": 1, "pageSize": 50}, {"code": 1})]

    @pytest.mark.parametrize("data,code",case_2)
    @allure.severity(allure.severity_level.MINOR)
    @pytest.mark.run(order=2)
    @allure.title("查询某一个用户名")
    @allure.story("查询某一个用户名:/api/admin/user/page/list")
    def test_case_02(self,get_xzs_cookie,data,code):
        """
        查询某一个用户名接口：/api/admin/user/page/list
        post
        {"userName":"student","role":1,"pageIndex":1,"pageSize":10}
        """
        res = requests.post(url=rc.get_xzsconfig()+"/api/admin/user/page/list",json=data,headers=get_xzs_cookie)
        assert res.status_code == 200
        assert res.json()["code"] == code.get("code")

    case_3 = [({"id":null,"userName":"pytest777","password":"123456","realName":"pytest","role":1,"status":1,"age":"",
    "sex":"","birthDay":null,"phone":null,"userLevel":1},{"message": "成功"}),    #'用户已存在'  '用户已存在' != '成功'
              ({"id":null,"userName":"￥%%…！%","password":"123456","realName":"pytest","role":1,"status":1,"age":"",
    "sex":"","birthDay":null,"phone":null,"userLevel":1},{"message": "失败"})]    #'用户已存在'  '用户已存在' != '成功'

    @pytest.mark.parametrize("data,message", case_3)
    @pytest.mark.run(order=3)
    @allure.severity(allure.severity_level.BLOCKER)
    @allure.title("添加用户名")
    @allure.story("添加用户名：/api/admin/user/edit")
    def test_case_03(self,data,message,get_xzs_cookie):
        """
        添加用户名接口：/api/admin/user/edit
        post
        {"id":null,"userName":"pytest1","password":"123456","realName":"pytest","role":1,"status":1,
        "age":"","sex":"","birthDay":null,"phone":null,"userLevel":1}
        """
        res = requests.post(url=rc.get_xzsconfig() + "/api/admin/user/edit",json=data,
                            headers=get_xzs_cookie)
        print(res.text)
        assert res.status_code == 200
        assert res.json()["message"] == message.get("message")

    @pytest.mark.run(order=4)
    @allure.severity(allure.severity_level.BLOCKER)
    @allure.title("删除用户名")
    @allure.story("删除用户名：/api/admin/user/delete/1342")
    def test_case_04(self,get_xzs_cookie):
        """
        删除用户名接口：/api/admin/user/delete/1342
        post
        {"code":1,"message":"成功","response":null}
        """
        res = requests.post(url=rc.get_xzsconfig() + "/api/admin/user/delete/1342",headers=get_xzs_cookie)
        print(res.text)
        assert res.status_code == 200
        assert '''"message":"成功"''' in res.text



